@@ -11,7 +11,7 @@ def naming(value):
 def naming_with_dashes(value):
     p = re.compile('^[A-Za-z0-9_-]+$')
     if not p.match(value):
-        raise ValidationError("String invalid. May contain [a-z0-9_-].")
+        raise ValidationError("String invalid. May contain [A-Za-z0-9_-].")
 
 
 def max_25_chars(value):
